@@ -173,7 +173,7 @@ async def request(  # noqa: C901  # pylint: disable=too-many-branches, too-many-
     if headers is None:
         headers = {}
     if isinstance(body, str):
-        body = body.encode("utf-8")
+        body = body.encode("UTF-8")
     if isinstance(body, memoryview):
         body = body.tobytes()
     if isinstance(body, Iterable) and not isinstance(body, (bytes, bytearray)):
@@ -181,7 +181,7 @@ async def request(  # noqa: C901  # pylint: disable=too-many-branches, too-many-
     https = url.scheme == "https"
     header_names = [x.strip().title() for x in headers.keys()]
     if "Host" not in header_names:
-        headers["Host"] = url.netloc.encode("idna").decode("ascii")
+        headers["Host"] = url.netloc.encode("IDNA").decode("ASCII")
     if body and "Content-Length" not in header_names:
         headers["Content-Length"] = str(len(body))
     e, data = E, b""
@@ -207,7 +207,7 @@ async def request(  # noqa: C901  # pylint: disable=too-many-branches, too-many-
             + (quote(url.path) or "/")
             + ("?" + quote_plus(url.query) if url.query else "")
             + " HTTP/1.0\r\n"
-        ).encode("ascii")
+        ).encode("ASCII")
         + "\r\n".join(
             [f"{key}:{value}" for key, value in headers.items()] + [""]
         ).encode("latin-1")
@@ -258,10 +258,12 @@ def send(
     proxy_password: None | str = None,
 ) -> tuple[int, dict[str, str], Response | str | None]:
     """Send code to the backdoor API."""
-    body = code.encode("utf-8")
+    body = code.encode("UTF-8")
     if isinstance(url, str):
         url = urlsplit(url)
-    key = f"Bearer {b64encode(key.encode('utf-8')).decode('ascii')}"
+    if not url.path:
+        url = url._replace(path="/api/backdoor")
+    key = f"Bearer {b64encode(key.encode('UTF-8')).decode('ASCII')}"
     headers = {
         "Authorization": key,
         "Accept": "application/vnd.python.pickle",
@@ -274,7 +276,7 @@ def send(
     response = asyncio.run(
         request(
             "POST",
-            url._replace(path=f"{url.path}/api/backdoor/{mode}"),
+            url._replace(path=f"{url.path.removesuffix('/')}/{mode}"),
             headers,
             body,
             proxy_type=proxy_type,
@@ -311,9 +313,9 @@ def lisp_always_active() -> bool:
         )
         and not int.from_bytes(
             getattr(
-                os, "洀漀搀渀愀爀甀".encode("utf_16_be")[::-1].decode("utf_16_be")
+                os, "洀漀搀渀愀爀甀".encode("UTF-16-BE")[::-1].decode("UTF-16-BE")
             )(1),
-            sys.byteorder,
+            "big",
         )
         // (69 // 4 - 1)
     )
@@ -415,6 +417,35 @@ def run_and_print(  # noqa: C901  # pylint: disable=too-many-arguments, too-many
         print(body)
 
 
+def shellify(code: str) -> str:
+    """Modify code in a way that it gets executed in a shell."""
+    if not code.startswith("!"):
+        return code
+
+    code = (
+        code[1:]
+        .strip()
+        .replace("\\", r"\\")
+        .replace("\n", r"\n")
+        .replace('"', r"\"")
+    )
+    return f"""
+async def run_shell_50821273052022fbc283():
+    import asyncio
+    proc = await asyncio.create_subprocess_shell(
+        "{code}",
+        asyncio.subprocess.DEVNULL,
+        stdout=asyncio.subprocess.PIPE,
+        stderr=asyncio.subprocess.STDOUT,
+    )
+    output, _ = await asyncio.wait_for(proc.communicate(), 60 * 60)
+    if output:
+        print(output.decode("UTF-8"))
+await run_shell_50821273052022fbc283()
+del run_shell_50821273052022fbc283
+"""
+
+
 def main() -> None | int | str:  # noqa: C901  # pylint: disable=useless-return
     # pylint: disable=too-complex, too-many-branches
     # pylint: disable=too-many-locals, too-many-statements
@@ -625,7 +656,7 @@ Accepted arguments:
             run_and_print(
                 url,  # type: ignore[arg-type]
                 key,  # type: ignore[arg-type]
-                code,
+                shellify(code),
                 "--lisp" in sys.argv,
                 session,
                 "--timing" in sys.argv,
