@@ -33,7 +33,7 @@ from configparser import ConfigParser
 from hashlib import sha256
 from multiprocessing import process
 from pathlib import Path
-from typing import Any, cast
+from typing import Any, Final, cast
 from zoneinfo import ZoneInfo
 
 import orjson
@@ -66,7 +66,12 @@ from . import (
     VERSION,
 )
 from .contact.contact import apply_contact_stuff_to_app
-from .quotes.utils import AUTHORS_CACHE, QUOTES_CACHE, WRONG_QUOTES_CACHE
+from .quotes.utils import (
+    AUTHORS_CACHE,
+    QUOTES_CACHE,
+    WRONG_QUOTES_CACHE,
+    update_cache_periodically,
+)
 from .utils import static_file_handling
 from .utils.base_request_handler import BaseRequestHandler
 from .utils.logging import WebhookFormatter, WebhookHandler
@@ -81,16 +86,16 @@ from .utils.utils import (
     time_function,
 )
 
-IGNORED_MODULES = {
+IGNORED_MODULES: Final[set[str]] = {
     "patches.*",
     "static.*",
     "templates.*",
 } | (set() if sys.flags.dev_mode else {"example.*"})
 
-CONFIG = ConfigParser(interpolation=None)
+CONFIG: Final[ConfigParser] = ConfigParser(interpolation=None)
 CONFIG.read("config.ini", encoding="UTF-8")
 
-logger = logging.getLogger(__name__)
+LOGGER: Final = logging.getLogger(__name__)
 
 
 # add all the information from the packages to a list
@@ -116,7 +121,7 @@ def get_module_infos() -> str | tuple[ModuleInfo, ...]:
         if _module_infos:
             module_infos.extend(_module_infos)
             loaded_modules.append(potential_module)
-            logger.info(
+            LOGGER.info(
                 "Found module_infos in %s.__init__.py, "
                 "do not search in other files in the module.",
                 potential_module,
@@ -141,15 +146,15 @@ def get_module_infos() -> str | tuple[ModuleInfo, ...]:
             # exit to make sure it gets fixed
             return "\n".join(errors)
         # don't exit in production to keep stuff running
-        logger.error("\n".join(errors))
+        LOGGER.error("\n".join(errors))
 
-    logger.info(
+    LOGGER.info(
         "Loaded %d modules: '%s'",
         len(loaded_modules),
         "', '".join(loaded_modules),
     )
 
-    logger.info(
+    LOGGER.info(
         "Ignored %d modules: '%s'",
         len(IGNORED_MODULES),
         "', '".join(IGNORED_MODULES),
@@ -173,7 +178,7 @@ def get_module_infos_from_module(
         package="an_website",
     )
     if import_timer.stop() > 0.1:
-        logger.warning(
+        LOGGER.warning(
             "Import of %s took %ss. That's affecting the startup time.",
             module_name,
             import_timer.execution_time,
@@ -294,10 +299,10 @@ def get_all_handlers(module_infos: tuple[ModuleInfo, ...]) -> list[Handler]:
     handlers.append((r"(?i)/api/*", RedirectHandler, {"url": "/api/endpunkte"}))
 
     handlers.append(
-        (r"/.well-known/(.*)", StaticFileHandler, {"path": ".well-known"})
+        (r"(?i)/\.well-known/(.*)", StaticFileHandler, {"path": ".well-known"})
     )
 
-    logger.debug("Loaded %d handlers", len(handlers))
+    LOGGER.debug("Loaded %d handlers", len(handlers))
 
     return handlers
 
@@ -318,7 +323,7 @@ def make_app(config: ConfigParser) -> str | Application:
     if isinstance(module_infos, str):
         return module_infos
     if duration > 1:
-        logger.warning(
+        LOGGER.warning(
             "Getting the module infos took %ss. That's probably too long.",
             duration,
         )
@@ -349,6 +354,10 @@ def apply_config_to_app(app: Application, config: ConfigParser) -> None:
         "GENERAL", "COOKIE_SECRET", fallback=b"xyzzy"
     )
 
+    app.settings["CRAWLER_SECRET"] = config.get(
+        "APP_SEARCH", "CRAWLER_SECRET", fallback=None
+    )
+
     app.settings["DOMAIN"] = config.get("GENERAL", "DOMAIN", fallback=None)
 
     app.settings["ELASTICSEARCH_PREFIX"] = config.get(
@@ -650,7 +659,7 @@ async def check_elasticsearch(app: Application) -> None:  # pragma: no cover
             await es.transport.perform_request("HEAD", "/")
         except Exception:  # pylint: disable=broad-except
             EVENT_ELASTICSEARCH.clear()
-            logger.exception("Connecting to Elasticsearch failed")
+            LOGGER.exception("Connecting to Elasticsearch failed")
         else:
             if not EVENT_ELASTICSEARCH.is_set():
                 try:
@@ -658,7 +667,7 @@ async def check_elasticsearch(app: Application) -> None:  # pragma: no cover
                         es, app.settings["ELASTICSEARCH_PREFIX"]
                     )
                 except Exception:  # pylint: disable=broad-except
-                    logger.exception(
+                    LOGGER.exception(
                         "An exception occured while configuring Elasticsearch"
                     )
                 else:
@@ -691,7 +700,7 @@ async def setup_elasticsearch_configs(  # noqa: C901
         base_path = Path(os.path.join(DIR, "elasticsearch", what))
         for path in base_path.rglob("*.json"):
             if not path.is_file():
-                logger.warning("%s is not a file", path)
+                LOGGER.warning("%s is not a file", path)
                 continue
 
             body = orjson.loads(
@@ -721,7 +730,7 @@ async def setup_elasticsearch_configs(  # noqa: C901
                 else:
                     await put(name=name, body=body)
             elif current_version > body.get("version", 1):
-                logger.warning(
+                LOGGER.warning(
                     "%s has version %s. The version in Elasticsearch is %s!",
                     path,
                     body.get("version", 1),
@@ -791,7 +800,7 @@ async def check_redis(app: Application) -> None:  # pragma: no cover
             await redis.ping()
         except Exception:  # pylint: disable=broad-except
             EVENT_REDIS.clear()
-            logger.exception("Connecting to Redis failed")
+            LOGGER.exception("Connecting to Redis failed")
         else:
             EVENT_REDIS.set()
         await asyncio.sleep(20)
@@ -829,16 +838,15 @@ def main() -> None | int | str:  # noqa: C901  # pragma: no cover
 
     This is the main function that is called when running this file.
     """
-    # pylint: disable=too-complex, too-many-branches
-    # pylint: disable=too-many-locals, too-many-statements
+    # pylint: disable=too-complex, too-many-branches, too-many-statements
     setproctitle(NAME)
     install_signal_handler()
     setup_logging(CONFIG)
 
-    logger.info("Starting %s %s", NAME, VERSION)
+    LOGGER.info("Starting %s %s", NAME, VERSION)
 
     if platform.system() == "Windows":
-        logger.warning(
+        LOGGER.warning(
             "Please note that running %s on Windows is not officially"
             " supported",
             NAME.removesuffix("-dev"),
@@ -889,7 +897,8 @@ def main() -> None | int | str:  # noqa: C901  # pragma: no cover
         os.makedirs(unix_socket_path, exist_ok=True)
         sockets.append(
             tornado.netutil.bind_unix_socket(
-                os.path.join(unix_socket_path, f"{NAME}.sock")
+                os.path.join(unix_socket_path, f"{NAME}.sock"),
+                mode=0o666,
             )
         )
 
@@ -918,7 +927,8 @@ def main() -> None | int | str:  # noqa: C901  # pragma: no cover
         if unix_socket_path:
             sockets.append(
                 tornado.netutil.bind_unix_socket(
-                    os.path.join(unix_socket_path, f"{NAME}.{task_id}.sock")
+                    os.path.join(unix_socket_path, f"{NAME}.{task_id}.sock"),
+                    mode=0o666,
                 )
             )
 
@@ -932,7 +942,7 @@ def main() -> None | int | str:  # noqa: C901  # pragma: no cover
 
     setup_webhook_logging(CONFIG, loop)
 
-    # pylint: disable=import-outside-toplevel, unused-variable
+    # pylint: disable=unused-variable
 
     wait_for_shutdown_task = loop.create_task(wait_for_shutdown())  # noqa: F841
 
@@ -942,8 +952,6 @@ def main() -> None | int | str:  # noqa: C901  # pragma: no cover
     if CONFIG.getboolean("REDIS", "ENABLED", fallback=False):
         check_redis_task = loop.create_task(check_redis(app))  # noqa: F841
 
-    from .quotes.utils import update_cache_periodically
-
     if not task_id:
         quotes_cache_update_task = loop.create_task(  # noqa: F841
             update_cache_periodically(app)
