@@ -25,7 +25,7 @@ import os
 import threading
 from collections.abc import Callable
 from pathlib import Path
-from typing import Any
+from typing import Any, Final
 
 import certifi
 import defusedxml  # type: ignore[import]
@@ -36,12 +36,13 @@ import tornado.web
 import uvloop
 import yaml
 from emoji import EMOJI_DATA
+from emoji import unicode_codes as euc
 from setproctitle import setthreadtitle
 
 from .. import DIR as ROOT_DIR
 from . import braille, json  # noqa: F401  # pylint: disable=reimported
 
-DIR = os.path.dirname(__file__)
+DIR: Final = os.path.dirname(__file__)
 
 with contextlib.suppress(ImportError):
     # pylint: disable=import-error, useless-suppression
@@ -141,10 +142,6 @@ def patch_emoji() -> None:
             "status": 2,
             "E": 11,
         }
-
-    # pylint: disable=import-outside-toplevel
-    import emoji.unicode_codes as euc
-
     for lang in euc.LANGUAGES:
         euc._EMOJI_UNICODE[lang] = None  # type: ignore[attr-defined]
     euc._ALIASES_UNICODE.clear()  # type: ignore[attr-defined]
